@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceTiddlerIconsPlugin|
-|''Version''|0.6.1|
+|''Version''|0.6.4|
 |''Status''|@@beta@@|
 |''Author''|Jon Robson|
 |''Description''|Provides ability to render SiteIcons and icons that correspond to the home location of given tiddlers|
@@ -55,26 +55,35 @@ config.macros.view.views.SiteIcon = function(value, place, params, wikifier,
 		pos = value.indexOf("_private");
 		value = value.substr(0, pos);
 	}
-
-	var args = paramString.parseParams("name", null, true, false, true)[0];
-	var labelPrefix = args.labelPrefix ? args.labelPrefix[0] : "";
-	var labelSuffix = args.labelSuffix ? args.labelSuffix[0] : "";
-	if(!store.tiddlerExists(tiddler.title) || value == "None") { // some core tiddlers lack modifier
-		value = "unknown";
-		if(store.tiddlerExists("missingIcon")) {
-			imageMacro.renderImage(imagePlace, "missingIcon", imageOptions);
-		}
-	} else {
-		getStatus(function(status) {
+	value = value.toLowerCase();
+	getStatus(function(status) {
+		var args = paramString.parseParams("name", null, true, false, true)[0];
+		var labelPrefix = args.labelPrefix ? args.labelPrefix[0] : "";
+		var labelSuffix = args.labelSuffix ? args.labelSuffix[0] : "";
+		var link;
+		var noLabel;
+		if(!store.tiddlerExists(tiddler.title) || value == "None") { // some core tiddlers lack modifier
+			value = "unknown";
+			link = value;
+			if(store.tiddlerExists("missingIcon")) {
+				imageMacro.renderImage(imagePlace, "missingIcon", imageOptions);
+			} else {
+				noLabel = true;
+			}
+		} else {
+			var spaceURI = tiddlyspace.getHost(status.server_host, value);
+			link = $("<a />").attr("href", spaceURI).text(value);
 			var uri = tiddlyspace.getAvatar(status.server_host, value);
 			imageMacro.renderImage(imagePlace, uri, imageOptions);
 			if(!value) {
 				value = "tiddlyspace";
 			}
-		});
-	}
-	$('<div class="label" />').text(labelPrefix + value + labelSuffix).
-		appendTo(container);
+		}
+		if(!noLabel) {
+			$('<div class="label" />').append(labelPrefix).append(link).append(labelSuffix).
+			appendTo(container);
+		}
+	});
 	$(container).attr("title", value).attr("alt", value);
 };
 
@@ -235,12 +244,18 @@ var originMacro = config.macros.tiddlerOrigin = {
 			originMacro.showPrivacyRoundel(tiddler, type, concertinaButton,
 				concertinaContentEl, options);
 		} else {
-			var label = locale.external.format([options.space.name || "tiddlyspace"]);
 			getStatus(function(status) {
+				var name = options.space.name;
+				var tooltip = name ? name : "tiddlyspace";
+				name = name ? '<a href="%0">%1</a>'.format([
+					tiddlyspace.getHost(status.server_host, name), name]) : "tiddlyspace";
+				var label = locale.external.format([name]);
+				tooltip = locale.external.format([tooltip]);
 				var uri = tiddlyspace.getAvatar(status.server_host, options.space.name);
 				imageMacro.renderImage(concertinaButton, uri, options.imageOptions);
 				var labelOptions = options.labelOptions;
 				labelOptions.label = label;
+				labelOptions.tooltip = tooltip;
 				originMacro.showLabel(concertinaButton, type, labelOptions);
 				originMacro.fillConcertina(concertinaContentEl, type, tiddler);
 			});
@@ -287,7 +302,13 @@ var originMacro = config.macros.tiddlerOrigin = {
 		// to do: not this is not enough.. we also need to check if the public tiddler is the same as..
 		// .. the private tiddler to determine whether this is a draft
 		// use of hashes would be useful here.
-		imageMacro.renderImage(concertinaButton, "%0Icon".format([privacyType]), options.imageOptions);
+		var icon = "%0Icon".format([privacyType]);
+		if(privacyType == "shadow") {
+			if(!store.tiddlerExists(icon)) {
+				icon = "bags/tiddlyspace/tiddlers/SiteIcon";
+			}
+		}
+		imageMacro.renderImage(concertinaButton, icon, options.imageOptions);
 		originMacro.showLabel(concertinaButton, privacyType, options.labelOptions);
 		originMacro.fillConcertina(concertinaContentEl, privacyType, thisTiddler);
 	},
@@ -296,15 +317,15 @@ var originMacro = config.macros.tiddlerOrigin = {
 
 		var tidEl = $(story.findContainingTiddler(concertinaButton));
 
-		label = options.label ? options.label : locale[type];
-
+		var label = options.label ? options.label : locale[type];
+		var tooltip = options.tooltip ? options.tooltip : locale[type];
 		tidEl.
 			removeClass("private public external privateAndPublic privateNotPublic shadow").
 			addClass(type);
 		if(options && options.includeLabel) {
-			$('<div class="roundelLabel" />').text(label || locale.unknown).appendTo(concertinaButton);
+			$('<div class="roundelLabel" />').html(label || locale.unknown).appendTo(concertinaButton);
 		}
-		$(concertinaButton).attr("title", label);
+		$(concertinaButton).attr("title", tooltip);
 	},
 	fillConcertina: function(place, privacyType, tiddler) {
 		if(!place) {
